@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1736 2025/08/03 13:56:55 rsadowski Exp $
+# $OpenBSD: Quirks.pm,v 1.1742 2025/08/18 12:22:03 daniel Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -633,6 +633,8 @@ my $stem_extensions = {
 	'compton-conf' => 'picom-config',
 	'minetest' => 'luanti',
 	'qcoro-qt6' => 'qcoro',
+	'libaccounts-qt6' => 'libaccounts-qt',
+	'kdsoap-qt6' => 'kdsoap-qt',
 };
 
 my $obsolete_reason = {};
@@ -1277,6 +1279,11 @@ setup_obsolete_reason(
 	12 => 'rcube-sieverules',
 	3 => 'rcube-yubikey-plugin',
 	3 => 'qjson',
+	3 => 'mysql-utilities',
+	5 => 'cdk',
+	5 => 'libdazzle',
+	5 => 'clutter-gst',
+	3 => 'bruce',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
